import {
  select,
	csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} from 'd3'

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');


const render = (data) => {
  const xValue = d => d.Weight;
  const yValue = d => d.Height;
  const xText = 'PESO (g)';
  const yText = 'ALTURA (cm)';
  const radius = 5;
  const colorX = '#003f5c';
  const colorY = '#ffa600';
  const margin = {top: 50, bottom: 180, left: 120, right: 70};
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const defineColor = d => d.Gender == 'Male'? colorX : colorY;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight])
  	.nice();
    
  const yAxis = axisLeft().scale(yScale);
  const xAxis = axisBottom().scale(xScale);

  yAxis.tickSize(-innerWidth);
  xAxis.tickSize(innerHeight);
  xAxis.tickPadding(13);
  yAxis.tickPadding(16);
  
  const g = select('svg').append('g');
	  
  const xAxisG = g.append('g').call(xAxis);
	const yAxisG = g.append('g').call(yAxis);  
    
  g.selectAll('circle').data(data)
  .enter().append('circle')
  .attr('cy', d => yScale(yValue(d)))
  .attr('cx', d => xScale(xValue(d)))
  .style('fill', d => defineColor(d))
  .attr('r', radius);

  g.attr('transform', `translate(${margin.left},${margin.top})`);

  xAxisG.selectAll('.domain').remove();
  yAxisG.selectAll('.domain').remove();
	
  xAxisG.append('text')
  	.attr('class', 'labelx')
  	.attr('x', innerWidth / 2)
  	.attr('y', innerHeight + 70)
    .text(xText)

  yAxisG.append('text')
  	.attr('class', 'labely')
  	.attr('x', -160)
  	.attr('y', -70)
  	.attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle')
    .text(yText)

}

//Height,Weight,Index
csv('crianca.csv').then(data => {
	data.forEach(d => {
  	d.Height = +d.Height;
    d.Weight = +d.Weight;
    d.Index = +d.Index;
  });
	
  render(data);
});
